import os
import sys
import argparse
import smtplib
from email.mime.text import MIMEText
from p3mail import consts
from pathlib import Path
from configparser import ConfigParser


def parse_config(fname=None):
    config_fname = Path.home() / ".config" / consts.prg_name / "config"

    if fname is not None:
        config_fname = fname

    config = ConfigParser()
    if len(config.read(config_fname)) == 0:
        raise ValueError("'{}' is an invalid config file".format(config_fname))
    return config["DEFAULT"]


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "subject", help="The subject of the mail", type=str)

    parser.add_argument(
        "--to", help="The receiver's address. If not provided, \
        it will look at the config file", type=str)

    # use dest=dest because 'from' is a Python reserved word
    parser.add_argument(
        "--from", help="The sender's address. If not provided, \
        it will look at the config file", type=str, dest="dest")

    parser.add_argument(
        "--config", help="Specify a custom location for the config file",
        type=str)

    return parser.parse_args()


def main():
    args = parse_args()

    custom_config_fname = args.config or None
    config = parse_config(fname=custom_config_fname)

    msg_text = sys.stdin.read()

    if len(msg_text) == 0:
        print("empty message body", file=sys.stderr)
        return

    msg = MIMEText(msg_text)
    msg['Subject'] = args.subject
    msg['From'] = args.dest or config["From"]
    msg['To'] = args.to or config["To"]

    s = smtplib.SMTP(config["SmtpServer"], port=config["SmtpPort"])

    smtp_user = config['SmtpUser'] or os.environ["SMTP_USER"]
    smtp_pass = config['SmtpPass'] or os.environ["SMTP_PASS"]
    s.login(smtp_user, smtp_pass)
    s.send_message(msg)
    s.quit()


if __name__ == '__main__':
    main()



import os
from setuptools import setup, find_packages
from p3mail import consts

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name=consts.prg_name,
    version="0.1",
    author="Gary Marigliano",
    author_email="gary-pypi@marigliano.ch",
    description=(consts.full_prg_name),
    keywords="mail pipe stdin",
    url="https://github.com/krypty/p3mail",
    packages=find_packages(),
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    entry_points={
        'console_scripts': [
            'p3mail=p3mail.p3mail:main'
        ],
    },
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python :: 3.5",
        "Topic :: Utilities",
    ],
)
